@@ -33,10 +33,15 @@ module GLib
   def exit_application(exception, status)
     msg = exception.message || exception.to_s
     msg = exception.class.to_s if msg == ""
-    backtrace = exception.backtrace
-    $stderr.puts backtrace.shift + ": #{msg}"
+    backtrace = exception.backtrace || []
+    first_line = backtrace.shift
+    if first_line
+      $stderr.puts("#{first_line}: #{msg}")
+    else
+      $stderr.puts(msg)
+    end
     backtrace.each do |v|
-      $stderr.puts "\t from #{v}"
+      $stderr.puts("\t from #{v}")
     end
     exit(status)
   end
@@ -182,7 +187,7 @@ module GLib
 
   module Log
     DOMAIN = "Ruby/GLib"
-    LEVELS = { 
+    LEVELS = {
       LEVEL_ERROR => "ERROR",
       LEVEL_CRITICAL => "CRITICAL",
       LEVEL_WARNING => "WARNING",
@@ -202,15 +207,23 @@ module GLib
       log(DOMAIN, LEVEL_CRITICAL, caller(1)[0] << ": " << str)
     end
     def warning(str)
-      log(DOMAIN,  LEVEL_WARNING, caller(1)[0] << ": " << str)
+      log(DOMAIN, LEVEL_WARNING, caller(1)[0] << ": " << str)
     end
-    
+
     def set_log_domain(domain)
-      level = GLib::Log::LEVEL_MASK
+      level =
+        FLAG_RECURSION |
+        FLAG_FATAL |
+        LEVEL_ERROR |
+        LEVEL_CRITICAL |
+        LEVEL_WARNING
+      if $VERBOSE or $DEBUG
+        level |=
+          LEVEL_MESSAGE |
+          LEVEL_INFO
+      end
       if $DEBUG
-        level = 255
-      elsif $VERBOSE
-        level = 127
+        level |= LEVEL_DEBUG
       end
       GLib::Log.set_handler(domain, level)
     end
